<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\Aksesmenu;
use App\Models\Menu;
use App\Models\User;
use App\Models\Userlevel;
use Auth;
use Redirect;
use Validator;

class UserController extends Controller
{
    public function __construct() {
        $this->middleware('auth');
    }

    public function index(Request $request)
    {
        // $referer = \Request::path();
        // $menu = Menu::where('link', $referer)->first();
        // $auth = Auth::user();
        // $akses_menu = Aksesmenu::where('id_level', $auth->id_level)->where('id_menu', $menu->id)->first();
        // if($akses_menu == NULL) {
        //     return redirect('/home');
        // }
        $filter = $request->query('filter');

        if(!empty($filter)) {
        $user = User::join('user_level', 'users.id_level', 'user_level.id')
                ->select('users.*', 'user_level.info')
                ->where('user.username', 'like', '%'.$filter.'%')
                ->orWhere('user.fullname', 'like', '%'.$filter.'%')
                ->orWhere('user_level.info', 'like', '%'.$filter.'%')
                ->paginate(10);
        } else {
            $user = User::join('user_level', 'users.id_level', 'user_level.id')
                    ->select('users.*', 'user_level.info')
                    ->paginate(10);
        }
        // return view('user.read')->with('user', $user)->with('filter', $filter)->with('akses_menu', $akses_menu);
        return view('user.read')->with('user', $user)->with('filter', $filter);
    }

    public function add()
    {
        $userLevel = Userlevel::get();
        return view('user.add', compact('userLevel'));
    }
    
    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'username' => 'required|unique:users',
            'password' => 'required',
            'fullname' => 'required',
        ], [
            'required' => ':attribute belum diisi',
            'unique' => ':attribute sudah ada',
        ]);

        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator);
        }

        $notification = array(
            'message' => 'Data User Telah Ditambahkan', 
            'alert_type' => 'success',
        );

        $password = \Hash::make($request->password);
        User::create([
            'username' => $request->username,
            'password' => $password,
            'fullname' => $request->fullname,
            'id_level' => $request->id_level,
            ]);
        
        return redirect('/user')->with('notification', $notification);
    }

    public function edit($id)
    {
        $user = User::find($id);
        $userLevel = Userlevel::pluck('info', 'id');
        return view('user.edit', compact('user', 'userLevel'));
    }

    public function update(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'username' => 'required|unique:users,username,'.$request->id,
            'password' => 'required',
        ], [
            'required' => ':attribute belum diisi',
            'unique' => ':attribute sudah ada',
        ]);

        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator);
        }

        $notification = array(
            'message' => 'Data User Telah Diubah', 
            'alert_type' => 'success',
        );

        $password = \Hash::make($request->password);
        User::where('id', $request->id)
                    ->update([
                        'username'=> $request->username,
                        'password'=> $password,
                        'fullname'=> $request->fullname,
                        'id_level'=> $request->id_level]);
        return redirect('/user')->with('notification', $notification);
    }

    public function destroy($id)
    {
        $notification = array(
            'message' => 'Data User Telah Dihapus', 
            'alert_type' => 'success',
        );

        User::find($id)->delete();
        return redirect('/user')->with('notification', $notification);
    }
}
